@@ -250,13 +250,33 @@ my %doc_for = (
             sort_order  => 30,
         },
         refers_to => {
-            keyword   => 'refers_to',
-            label     => 'Foreign Key Table',
-            descr     => 'Table this foreign key points to',
-            type      => 'text',
-            multiple  => 0,
-            urgency   => 1,
-            sort_order => 40,
+            keyword       => 'refers_to',
+            label         => 'Foreign Key Table',
+            descr         => 'Where this foreign key points',
+            type          => 'pair',
+            pair_labels   => [ 'Table', 'Column' ],
+            pair_required => 0,
+            multiple      => 0,
+            urgency       => 1,
+            sort_order    => 40,
+        },
+        on_delete => {
+            keyword  => 'on_delete',
+            label    => 'On Delete Behavior',
+            descr    => 'What to do when foreign key column\'s row dies',
+            type     => 'text',
+            multiple => 0,
+            urgency   => 0,
+            sort_order => 50,
+        },
+        on_update => {
+            keyword  => 'on_update',
+            label    => 'On Update Behavior',
+            descr    => 'What to do when foreign key column\'s row changes',
+            type     => 'text',
+            multiple => 0,
+            urgency   => 0,
+            sort_order => 51,
         },
         label => {
             keyword  => 'label',
